#!/bin/bash
# Test that the code generated by AutoFactory is compatible with Java 7.
# The AutoFactory processor itself runs on Java 8, but the code it
# generates is supposed to be able to run on Java 7.
#
# Users can achieve that by compiling like this:
#   javac --release 7
#
# So this test does the same thing, using a large functional test as input.
# If that test compiles, it is a good sign that user code will compile and run.

# Exit if any command fails.
set -e

# Arguments are
# * the path to the JDK
# * the fully-qualified name of the test class
# * the path to each source file.

JAVABASE="$1"
shift

TEST_CLASS="$1"
if [ -z "${TEST_CLASS}" ]; then
  echo "Usage: $0 JAVABASE TEST_NAME" >&2
  exit 1
fi
shift

MY_DIR=$(dirname "${TEST_BINARY}")
SOURCE_FILES=$(for f in "$@"; do echo "${MY_DIR}/${f}"; done)

JAVAC="${JAVABASE}"/bin/javac
CLASS_PATH="${MY_DIR}"/java7_compat_test_java_deps.jar
PROCESSOR_PATH=\
third_party/java/auto/auto_factory_ide.jar:\
third_party/java/dagger/dagger_components_ide.jar

"${JAVAC}" -d "${TEST_TMPDIR}" \
    -encoding utf8 --release 7 \
    -classpath "${CLASS_PATH}" \
    -processorpath "${PROCESSOR_PATH}" \
    ${SOURCE_FILES}
